# Generated by ariadne-codegen
# Source: operations.graphql

from .base_model import BaseModel
from .fragments import PaywallFragment


class GetPaywall(BaseModel):
    paywall: "GetPaywallPaywall"


class GetPaywallPaywall(PaywallFragment):
    pass


GetPaywall.model_rebuild()



# Generated by ariadne-codegen
# Source: operations.graphql

from typing import List

from pydantic import Field

from .base_model import BaseModel
from .fragments import PromotionalEntitlementFragment


class GrantPromotionalEntitlementsGroup(BaseModel):
    grant_promotional_entitlements_group: List[
        "GrantPromotionalEntitlementsGroupGrantPromotionalEntitlementsGroup"
    ] = Field(alias="grantPromotionalEntitlementsGroup")


class GrantPromotionalEntitlementsGroupGrantPromotionalEntitlementsGroup(
    PromotionalEntitlementFragment
):
    pass


GrantPromotionalEntitlementsGroup.model_rebuild()



# Generated by ariadne-codegen
# Source: operations.graphql

from pydantic import Field

from .base_model import BaseModel
from .fragments import AutoRechargeSettingsFragment


class GetAutomaticRechargeConfiguration(BaseModel):
    get_auto_recharge_settings: "GetAutomaticRechargeConfigurationGetAutoRechargeSettings" = Field(
        alias="getAutoRechargeSettings"
    )


class GetAutomaticRechargeConfigurationGetAutoRechargeSettings(
    AutoRechargeSettingsFragment
):
    pass


GetAutomaticRechargeConfiguration.model_rebuild()
